<?php
// Version: 2.0 RC1; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '2.0 RC1';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status separate from topic icons? */
	$settings['separate_sticky_lock'] = true;

	/* Does this theme use the strict doctype? */
	$settings['strict_doctype'] = false;

	/* Does this theme use post previews on the message index? */
	$settings['message_index_preview'] = false;
	
	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = true;
	
	// load custom language strings
	loadLanguage('ThemeStrings');
	
	// Color changer
	if(!$context['user']['is_guest'] && isset($_POST['options']['theme_color']))
	{
	   include_once($GLOBALS['sourcedir'] . '/Profile-Modify.php');
	   makeThemeChanges($context['user']['id'], $settings['theme_id']);
	   $options['theme_color'] = $_POST['options']['theme_color'];
	}
	elseif ($context['user']['is_guest'])
	{
	   if (isset($_POST['options']['theme_color']))
	   {
		  $_SESSION['theme_color'] = $_POST['options']['theme_color'];
		  $options['theme_color'] = $_SESSION['theme_color'];
	   }
	   elseif (isset($_SESSION['theme_color']))
		  $options['theme_color'] = $_SESSION['theme_color'];
	}

}

// The main sub template above the content.
function template_html_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title_html_safe'], '" />
	<meta name="keywords" content="', $context['meta_keywords'], '" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/script.js?rc1"></script>
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/theme.js?rc1"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_default_theme_url = "', $settings['default_theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";', $context['show_pm_popup'] ? '
		if (confirm("' . $txt['show_personal_messages'] . '"))
			window.open(smf_prepareScriptUrl(smf_scripturl) + "action=pm");' : '', '
		var ajax_notification_text = "', $txt['ajax_in_progress'], '";
		var ajax_notification_cancel_text = "', $txt['modify_cancel'], '";
	// ]]></script>
	<title>', $context['page_title_html_safe'], '</title>';
	
	// Any color set by user?
	if (isset($options['theme_color']))
		$settings['theme_main_color'] = $options['theme_color'];

	// If not set, or if not allowed to set
	if(!isset($options['theme_color']) || (isset($settings['allow_color_change']) && $settings['allow_color_change'] == 'no'))
	{
		// Defaults.
		$options['theme_color'] = isset($settings['theme_main_color']) ? $settings['theme_main_color'] : '';
		$settings['theme_main_color'] = $options['theme_color'];
	}

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="noindex" />';

	// The ?rc1 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style', $context['theme_variant'], '.css?rc1" />
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style_' , $settings['theme_main_color'] , '.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';

	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/print.css?rc1" media="print" />';

	// IE7 needs some fixes for styles.
	if ($context['browser']['is_ie7'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ie7.css" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';
	// ..and IE6!
	elseif ($context['browser']['is_ie6'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ie6.css" />';
	// Firefox - all versions - too!
	elseif ($context['browser']['is_firefox'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ff.css" />';

	// RTL languages require an additional stylesheet.
	if ($context['right_to_left'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/rtl.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name_html_safe'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="', $scripturl, '?board=', $context['current_board'], '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
	{
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);
		$options['collapse_header_ic'] = !empty($_COOKIE['upshrinkIC']);
	}

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		// Create the main header object.
		var mainHeader = new smfToggle("upshrink", ', empty($options['collapse_header']) ? 'false' : 'true', ');
		mainHeader.useCookie(', $context['user']['is_guest'] ? 1 : 0, ');
		mainHeader.setOptions("collapse_header", "', $context['session_id'], '");
		mainHeader.addToggleImage("upshrink", "/upshrink.gif", "/upshrink2.gif");
		mainHeader.addTogglePanel("user_section");
		mainHeader.addTogglePanel("news_section");
	// ]]></script>';

	echo '
</head>
<body>';
}

function template_body_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
	<div id="header-l">
	    <div id="header-r">
		<div id="header">
			<div id="userarea" class="smalltext">';
				if($context['user']['is_logged'])
				{
					echo $txt['hello_member_ndt'] , ' <strong>' , $context['user']['name'] , '</strong><br />';

					// If the user is logged in, display stuff like their name, new messages, etc.
	if ($context['user']['is_logged'])

		echo '
					
				
					<a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a><br />
					<a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a>';

					// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
			echo '
					<li class="notice">', $txt['maintain_mode_on'], '</li>';


					// Are there any members waiting for approval?
						if (!empty($context['unapproved_members']))
						echo '[<a href="', $scripturl, '?action=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] , '', $txt['approve'], '</a> ]';

						
				}
				// Otherwise they're a guest - this time ask them to either register or login - lazy bums...
				else
				{
				echo '
						<div style="margin-right: 110px;">', sprintf($txt['welcome_guest'], $txt['guest_title']), '</div>
			<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>
				<form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" style="margin: 3px 1ex 1px 0;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
								  <span class="quick" style="display: block;">
                        <span class="yoo-login">
                           <span class="login">
                              <span class="username">
									 <input type="text" name="user" size="18" alt="' , $txt[35] , '" value="' , $txt[username] , '" onfocus="if(this.value==\'' , $txt[username] , '\')value=\'\';" onblur="if(this.value==\'\')value=\'' , $txt[username] , '\';"  /> </span>
		<span class="password"> <input type="password" name="passwrd" size="10" value="Password" onfocus="if(this.value==\'Password\')value=\'\';" onblur="if(this.value==\'\')value=\'Password\';" /> </span>
									<span class="login-button-icon">
                              <button value="', $txt[login], '" name="Submit" type="submit" title="', $txt[login], '"></button>
                           </span>
                           <span class="lostpassword">
                              <a href="', $scripturl, '?action=reminder" title="' , $txt[forgot_your_password] , '"></a>
                           </span>
                           <span class="activatecode">
                           <a href="' . $scripturl . '?action=activate" title="' , $txt['activate_code'] , '"></a>
                           </span>
                           <span class="registration">
                           <a href="', $scripturl, '?action=register" title="' , $txt[register] , '"></a>
                           </span> </span>            
                        </span>
                        </span><br /><br /><div style="margin: -8px 190px 0px 0px;">', $txt[always_logged_in], ': <input type="checkbox" name="cookieneverexp"', $context['never_expire'] ? ' checked="checked"' : '', ' class="check" onclick="this.form.cookielength.disabled = this.checked;" /></div><br />
									
									<input type="hidden" name="hash_passwrd" value="" />
								
							</form>';
				}
		echo '
			</div><div id="logo"><div id="themename">
<a href="'.$scripturl.'">', $context['forum_name_html_safe'], '<span class="italic"></span></a></div>&nbsp;</div>
			
	</div></div></div><br /><br />
	<div class="bar-l">
					<div class="bar-r">
						<div class="bar">
		<table width="102%" cellpadding="4" cellspacing="0" border="0">
			<tr>';

	// Colors..!!
		echo '
				<td width="90%"><br />
					<form action="" method="post">
					<input title="', $txt[flag1], '" id="default" type="submit" value="" name="options[theme_color]"/>
					<input title="', $txt[flag2], '" id="style_00" type="submit" value="00" name="options[theme_color]"/>
					<input title="', $txt[flag3], '" id="style_05" type="submit" value="05" name="options[theme_color]"/>
					<input title="', $txt[flag4], '" id="style_10" type="submit" value="10" name="options[theme_color]"/>
					<input title="', $txt[flag5], '" id="style_15" type="submit" value="15" name="options[theme_color]"/>
					<input title="', $txt[flag6], '" id="style_20" type="submit" value="20" name="options[theme_color]"/>
					<input title="', $txt[flag7], '" id="style_25" type="submit" value="25" name="options[theme_color]"/>
					<input title="', $txt[flag8], '" id="style_30" type="submit" value="30" name="options[theme_color]"/>
					<input title="', $txt[flag9], '" id="style_35" type="submit" value="35" name="options[theme_color]"/>
					<input title="', $txt[flag10], '" id="style_40" type="submit" value="40" name="options[theme_color]"/>
					<input title="', $txt[flag11], '" id="style_45" type="submit" value="45" name="options[theme_color]"/>
					<input title="', $txt[flag12], '" id="style_50" type="submit" value="50" name="options[theme_color]"/>
					<input title="', $txt[flag13], '" id="style_55" type="submit" value="55" name="options[theme_color]"/>
					<input title="', $txt[flag14], '" id="style_60" type="submit" value="60" name="options[theme_color]"/>
					<input title="', $txt[flag15], '" id="style_65" type="submit" value="65" name="options[theme_color]"/>
					<input title="', $txt[flag16], '" id="style_70" type="submit" value="70" name="options[theme_color]"/>
					<input title="', $txt[flag17], '" id="style_75" type="submit" value="75" name="options[theme_color]"/>
					<input title="', $txt[flag18], '" id="style_80" type="submit" value="80" name="options[theme_color]"/>
					<input title="', $txt[flag19], '" id="style_85" type="submit" value="85" name="options[theme_color]"/>
					<input title="', $txt[flag20], '" id="style_90" type="submit" value="90" name="options[theme_color]"/>
					<input title="', $txt[flag21], '" id="style_95" type="submit" value="95" name="options[theme_color]"/>
					<input title="', $txt[flag22], '" id="style_100" type="submit" value="100" name="options[theme_color]"/>
					<input title="', $txt[flag23], '" id="style_105" type="submit" value="105" name="options[theme_color]"/>
					<input title="', $txt[flag24], '" id="style_110" type="submit" value="110" name="options[theme_color]"/>
					<input title="', $txt[flag25], '" id="style_115" type="submit" value="115" name="options[theme_color]"/>
					<input title="', $txt[flag26], '" id="style_120" type="submit" value="120" name="options[theme_color]"/>
					<input title="', $txt[flag27], '" id="style_125" type="submit" value="125" name="options[theme_color]"/>
					<input title="', $txt[flag28], '" id="style_130" type="submit" value="130" name="options[theme_color]"/>
					<input title="', $txt[flag29], '" id="style_135" type="submit" value="135" name="options[theme_color]"/>
				</form>

				</td>';
	echo '
				<td align="right" nowrap="nowrap" valign="top"><br />
	<form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '" style="margin: 0;">
<div class="search">
		<input name="search" class="inputbox" alt="" type="text" size="20" value="', $txt[search], '..." onfocus="this.value = \'\';" onblur="if(this.value==\'\') this.value=\'', $txt[search], '...\';" /><input type="submit" value="." class="button"/>	</div>';
	// Search within current topic?
	if (!empty($context['current_topic']))
		echo '
						<input type="hidden" name="topic" value="', $context['current_topic'], '" />';

		// If we're on a certain board, limit it to this board ;).
	elseif (!empty($context['current_board']))
		echo '
						<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';

	echo '
					</form>				
				</td>
			</tr>
		</table>
</div></div>';


	// Show the menu here, according to the menu sub template.
		echo '<br /><br /><br /><br /><div id="menu"><div id="toolbar-l">
				<div id="toolbar-r">
					<div id="toolbar">
						',template_menu(),'
					</div>
				</div>
			</div></div></div>
		<br /><br /><br /><br /><br /><br /><br />
			
				
			<div class="bodyarea" style="padding: 1ex 0px 2ex 0px;">';

		// Show the navigation tree.
		theme_linktree();

}

function template_body_below()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
			</div>';

	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '
		
<div id="footer-m">
	  <div id="footer-l">
	    <div id="footer-r">
            <div id="footer">
				<table cellspacing="0" cellpadding="3" border="0" align="center" width="100%">
			<tr>
				<td width="28%" valign="top" align="', !$context['right_to_left'] ? 'right' : 'left', '">
					<a href="http://www.mysql.com/" target="_blank"><img id="powered-mysql" src="', $settings['images_url'], '/powered-mysql.gif" alt="', $txt['powered_by_mysql'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
					<a href="http://www.php.net/" target="_blank"><img id="powered-php" src="', $settings['images_url'], '/powered-php.gif" alt="', $txt['powered_by_php'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
				</td>
				<td valign="top" align="center" style="white-space: nowrap;">
					<div class="footer">', theme_copyright(), '<br />WMC theme by <a href="http://wannabedie.deviantart.com/" target="_blank">WannaBeDie</a></div>
				</td>
				<td width="28%" valign="top" align="', !$context['right_to_left'] ? 'left' : 'right', '">
					<a href="http://validator.w3.org/check/referer" target="_blank"><img id="valid-xhtml10" src="', $settings['images_url'], '/valid-xhtml10.gif" alt="', $txt['valid_xhtml'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
					<a href="http://jigsaw.w3.org/css-validator/check/referer" target="_blank"><img id="valid-css" src="', $settings['images_url'], '/valid-css.gif" alt="', $txt['valid_css'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
				</td>
			</tr>
		</table>';

				// Show the load time?
				if ($context['show_load_time'])
				echo '<br />
					<span class="smalltext">', $txt['page_created'], $context['load_time'], $txt['seconds_with'], $context['load_queries'], $txt['queries'], '</span>';

		echo '
			</div></div></div>
		</div>';
}

function template_html_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
</body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree($force_show = false)
{
	global $context, $settings, $options, $shown_linktree;

	// If linktree is empty, just return - also allow an override.
	if (empty($context['linktree']) || (!empty($context['dont_default_linktree']) && !$force_show))
		return;

	//!!! Temporarily don't do it twice.
	if (!empty($shown_linktree))
		return;
	$shown_linktree = true;

	echo '
	<ul id="linktree">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		echo '
		<li', ($link_num == count($context['linktree']) - 1) ? ' class="last"' : '', '>';
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo $settings['linktree_link'] && isset($tree['url']) ? '
			<a href="' . $tree['url'] . '"><span>' . $tree['name'] . '</span></a>' : '<span>' . $tree['name'] .'</span>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;>';

		echo '
		</li>';
	}
	echo '
	</ul>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
		<div id="topmenu">
			<ul>';

			foreach ($context['menu_buttons'] as $act => $button)
				echo '<li><a ', $button['active_button'] ? ' class="current"' : '' , ' href="', $button['href'], '"><span>', $button['title'], '</span></a></li>';

	echo '
			</ul>
		</div>';
}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $context, $txt, $scripturl;

	// Create the buttons...
	$buttons = array();
	foreach ($button_strip as $key => $value)
	{
		if (!isset($value['test']) || !empty($context[$value['test']]))
			$buttons[] = '<a href="' . $value['url'] . '" ' . (isset($value['custom']) ? $value['custom'] : '') . '><span>' . $txt[$value['text']] . '</span></a>';
	}

	if (empty($buttons))
		return '';

	// Make the last one, as easy as possible.
	$buttons[count($buttons) - 1] = str_replace('<span>', '<span class="last">', $buttons[count($buttons) - 1]);

	echo '
		<div class="buttonlist', $direction != 'top' ? '_bottom' : '', '">
			<ul class="clearfix">
				<li>', implode('</li><li>', $buttons), '</li>
			</ul>
		</div>';

}

?>